@@ -157,6 +157,7 @@
 #include <e-util/e-markdown-utils.h>
 #include <e-util/e-menu-bar.h>
 #include <e-util/e-menu-tool-button.h>
+#include <e-util/e-message-popover.h>
 #include <e-util/e-misc-utils.h>
 #include <e-util/e-mktemp.h>
 #include <e-util/e-month-widget.h>
@@ -212,6 +213,7 @@
 #include <e-util/e-spell-dictionary.h>
 #include <e-util/e-spell-entry.h>
 #include <e-util/e-spell-text-view.h>
+#include <e-util/e-split-date-edit.h>
 #include <e-util/e-spinner.h>
 #include <e-util/e-stock-request.h>
 #include <e-util/e-table-click-to-add.h>
